From mboxrd@z Thu Jan 1 00:00:00 1970 Return-Path: Received: (majordomo@vger.kernel.org) by vger.kernel.org via listexpand id S1753818AbdBVFEr (ORCPT ); Wed, 22 Feb 2017 00:04:47 -0500 Received: from mail-pg0-f65.google.com ([74.125.83.65]:33024 "EHLO mail-pg0-f65.google.com" rhost-flags-OK-OK-OK-OK) by vger.kernel.org with ESMTP id S1750921AbdBVFEk (ORCPT ); Wed, 22 Feb 2017 00:04:40 -0500 From: Balbir Singh X-Google-Original-From: Balbir Singh Date: Wed, 22 Feb 2017 16:04:25 +1100 To: Anshuman Khandual Cc: linux-kernel@vger.kernel.org, linux-mm@kvack.org, mhocko@suse.com, vbabka@suse.cz, mgorman@suse.de, minchan@kernel.org, aneesh.kumar@linux.vnet.ibm.com, bsingharora@gmail.com, srikar@linux.vnet.ibm.com, haren@linux.vnet.ibm.com, jglisse@redhat.com, dave.hansen@intel.com, dan.j.williams@intel.com, zi.yan@cs.rutgers.edu Subject: Re: [PATCH 0/6] Enable parallel page migration Message-ID: <20170222050425.GB9967@balbir.ozlabs.ibm.com> References: <20170217112453.307-1-khandual@linux.vnet.ibm.com> MIME-Version: 1.0 Content-Type: text/plain; charset=us-ascii Content-Disposition: inline In-Reply-To: <20170217112453.307-1-khandual@linux.vnet.ibm.com> User-Agent: Mutt/1.7.1 (2016-10-04) Sender: linux-kernel-owner@vger.kernel.org List-ID: X-Mailing-List: linux-kernel@vger.kernel.org On Fri, Feb 17, 2017 at 04:54:47PM +0530, Anshuman Khandual wrote: > This patch series is base on the work posted by Zi Yan back in > November 2016 (https://lkml.org/lkml/2016/11/22/457) but includes some > amount clean up and re-organization. This series depends on THP migration > optimization patch series posted by Naoya Horiguchi on 8th November 2016 > (https://lwn.net/Articles/705879/). Though Zi Yan has recently reposted > V3 of the THP migration patch series (https://lwn.net/Articles/713667/), > this series is yet to be rebased. > > Primary motivation behind this patch series is to achieve higher > bandwidth of memory migration when ever possible using multi threaded > instead of a single threaded copy. Did all the experiments using a two > socket X86 sytsem (Intel(R) Xeon(R) CPU E5-2650). All the experiments > here have same allocation size 4K * 100000 (which did not split evenly > for the 2MB huge pages). Here are the results. > > Vanilla: > > Moved 100000 normal pages in 247.000000 msecs 1.544412 GBs > Moved 100000 normal pages in 238.000000 msecs 1.602814 GBs > Moved 195 huge pages in 252.000000 msecs 1.513769 GBs > Moved 195 huge pages in 257.000000 msecs 1.484318 GBs > > THP migration improvements: > > Moved 100000 normal pages in 302.000000 msecs 1.263145 GBs Is there a decrease here for normal pages? > Moved 100000 normal pages in 262.000000 msecs 1.455991 GBs > Moved 195 huge pages in 120.000000 msecs 3.178914 GBs > Moved 195 huge pages in 129.000000 msecs 2.957130 GBs > > THP migration improvements + Multi threaded page copy: > > Moved 100000 normal pages in 1589.000000 msecs 0.240069 GBs ** Ditto? > Moved 100000 normal pages in 1932.000000 msecs 0.197448 GBs ** > Moved 195 huge pages in 54.000000 msecs 7.064254 GBs *** > Moved 195 huge pages in 86.000000 msecs 4.435694 GBs *** > Could you also comment on the CPU utilization impact of these patches. Balbir Singh.